@@ -4,7 +4,7 @@ use strict;
 
 use Debug::Easy;
 my @LogLevel  = qw( ERR WARN NOTICE INFO DEBUG DEBUGMAX );
-my @CodeLevel = ('[ ERROR ]', '[WARNING]', '[NOTICE ]', '[ INFO  ]', '[ DEBUG ]', '[-DEBUG-]');
+my @CodeLevel = ('[ ERROR ]', '[WARNING]', '[NOTICE ]', '[ INFO  ]', '[ DEBUG ]', '[DEBUGMX]');
 my %SomeHash  = (
     'Thiskey' => 'ThisValue',
     'ThatKey' => 'ThatValue',
