@@ -27,7 +27,7 @@ BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.14;
+    our $VERSION = 1.15;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -123,7 +123,7 @@ Generally all you need are the defaults and you are ready to go.
 =cut
 
 END {    # We spit out one last message before we die, the total execute time.
-    my $bench = colored(['bright_cyan on_black'], sprintf('%06s', sprintf('%.02f', (time - $MASTERSTART))));
+    my $bench = colored(['bright_cyan'], sprintf('%06s', sprintf('%.02f', (time - $MASTERSTART))));
     my $name = $SCRIPTNAME;
     $name .= ' [child]' if ($PARENT ne $$);
     $LOG->DEBUG(' %s%s %s', $bench, $ANSILevel{'DEBUG'}, colored(['black on_white'], "---- $name complete ----")) if (defined($ANSILevel{'DEBUG'}) && defined($LOG));
@@ -201,22 +201,25 @@ A string that is parsed into the output prefix.
 
 DEFAULT:  '%Date% %Time% %Benchmark% %Loglevel%[%Subroutine%][%Lastline%] '
 
-%Date%       = Date (Uses format of "DateStamp" below)
-%Time%       = Time (Uses format of "TimeStamp" below)
-%Benchmark%  = Benchmark
-%Loglevel%   = Log Level
-%Lines%      = Line Numbers of all nested calls
-%Module%     = Module and subroutine of call (can be a lot of stuff!)
-%Subroutine% = Just the last subroutine
-%Lastline%   = Just the last line number
-%PID%        = Process ID
-%date%       = Just Date (typically used internally only, use %D)
-%time%       = Just time (typically used internally only, use %T)
-%Filename%   = Script Filename (parsed $0)
-%Fork%       = Running in parent or child?
+ %Date%       = Date (Uses format of "DateStamp" below)
+ %Time%       = Time (Uses format of "TimeStamp" below)
+ %Benchmark%  = Benchmark - The time it took between the last benchmark display
+                of this loglevel.  If in an INFO level message, it benchmarks
+                the time until the next INFO level message.  The same rule is
+                true for all loglevels.
+ %Loglevel%   = Log Level
+ %Lines%      = Line Numbers of all nested calls
+ %Module%     = Module and subroutine of call (can be a lot of stuff!)
+ %Subroutine% = Just the last subroutine
+ %Lastline%   = Just the last line number
+ %PID%        = Process ID
+ %date%       = Just Date (typically used internally only, use %Date%)
+ %time%       = Just time (typically used internally only, use %Time%)
+ %Filename%   = Script Filename (parsed $0)
+ %Fork%       = Running in parent or child?
      P = Parent
      C = Child
-%Thread%     = Running in Parent or Thread
+ %Thread%     = Running in Parent or Thread
      P   = Parent
      T## = Thread # = Thread ID
 
@@ -318,12 +321,12 @@ B<unix>
 =over 8
 
   'ANSILevel' => {
-     'ERR'       => colored(['white on_red'],       '[ ERROR ]'),
-     'WARN'      => colored(['black on_yellow'],    '[WARNING]'),
-     'NOTICE'    => colored(['black on_magenta'],   '[NOTICE ]'),
-     'INFO'      => colored(['white on_black'],     '[ INFO  ]'),
-     'DEBUG'     => colored(['bold green on_black'],'[ DEBUG ]'),
-     'DEBUGMAX'  => colored(['bold green on_black'],'[-DEBUG-]'),
+     'ERR'      => colored(['white on_red'],        '[ ERROR ]'),
+     'WARN'     => colored(['black on_yellow'],     '[WARNING]'),
+     'NOTICE'   => colored(['yellow'],              '[NOTICE ]'),
+     'INFO'     => colored(['black on_white'],      '[ INFO  ]'),
+     'DEBUG'    => colored(['bold green'],          '[ DEBUG ]'),
+     'DEBUGMAX' => colored(['bold black on_green'], '[DEBUGMX]'),
   }
 
 
@@ -353,8 +356,8 @@ sub new {
         'DEBUGMAX_LastStamp' => time,                                    # Initialize the DEBUGMAX benchmark
         'LOG'                => $LOG,                                    # Pull in the global Log::Fast object.
         'Color'              => TRUE,                                    # Default to colorized output
-        'DateStamp'          => colored(['yellow on_black'], '%date%'),
-        'TimeStamp'          => colored(['yellow on_black'], '%time%'),
+        'DateStamp'          => colored(['yellow'], '%date%'),
+        'TimeStamp'          => colored(['yellow'], '%time%'),
         'Padding'            => -20,                                     # Default padding is 20 spaces
         'Lines-Padding'      => -2,
         'Subroutine-Padding' => 0,
@@ -462,7 +465,7 @@ sub debug {
     my $msgs  = shift;
 
     if ($level !~ /ERR.*|WARN.*|NOTICE|INFO.*|DEBUG/i) {    # Compatibility with older versions.
-        $level = $msgs;                                     # It tosses the legacy __LINE__ argument
+        $level = uc($msgs);                                 # It tosses the legacy __LINE__ argument
         $msgs  = shift;
     }
     $level = 'ERR'  if ($level eq 'ERROR');                 # This allows the programmer to use either
@@ -536,7 +539,6 @@ sub debug {
 
     # Figure out the benchmarks, but only if it is in the prefix
     if ($self->{'PREFIX'} =~ /\%Benchmark\%/) {
-
         # For multiline output, only output the bench data on the first line.  Use padded spaces for the rest.
         #        $thisBench  = sprintf('%7s', sprintf(' %.02f', time - $self->{$level . '_LASTSTAMP'}));
         $thisBench = sprintf('%7s', sprintf(' %.02f', time - $self->{'ANY_LASTSTAMP'}));
@@ -575,16 +577,16 @@ sub _send_to_logger {      # This actually simplifies the previous object ... se
     my $sline      = shift;
     my $shortsub   = shift;
 
-    my $dt     = DateTime->now('time_zone' => $TIMEZONE);
-    my $Date   = $dt->ymd();
-    my $Time   = $dt->hms();
-    my $prefix = $self->{$level . '-PREFIX'} . '';    # A copy not a pointer
-    my $forked = ($PARENT ne $$) ? 'C' : 'P';
-    my $threaded = 'P--';
+    my $dt       = DateTime->now('time_zone' => $TIMEZONE);
+    my $Date     = $dt->ymd();
+    my $Time     = $dt->hms();
+    my $prefix   = $self->{$level . '-PREFIX'} . '';    # A copy not a pointer
+    my $forked   = ($PARENT ne $$) ? 'C' : 'P';
+    my $threaded = 'PT-';
     if ($Config{'useithreads'}) { # Do eval so non-threaded perl's don't whine
         eval(q(
-            my $tid = threads->tid();
-            $threaded = ($tid > 0) ? sprintf('T%02',$tid) : 'P--';
+            my $tid   = threads->tid();
+            $threaded = ($tid > 0) ? sprintf('T%02d',$tid) : 'PT-';
         ));
     }
 
@@ -772,13 +774,13 @@ OR you can use the old ExtUtils::MakeMaker method:
 
 Richard Kelsch <rich@rk-internet.com>
 
-Copyright 2013 Richard Kelsch, All Rights Reserved.
+Copyright 2013-2016 Richard Kelsch, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 B<VERSION>
 
-Version 1.11    (February 10, 2016)
+Version 1.15    (October 19, 2016)
 
 =head1 B<BUGS>
 
